@@ -499,8 +499,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "Linux"
-#define MACHINE_TYPE "armv7l"
-#define DEFAULT_MACHINE "armv7l"
+#define MACHINE_TYPE "armv5tel"
+#define DEFAULT_MACHINE "armv5tel"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -641,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 31
+#define MYSQL_VERSION_PATCH 32
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.31"
+#define PACKAGE_STRING "MySQL Server 10.1.32"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.31"
-#define VERSION "10.1.31"
+#define PACKAGE_VERSION "10.1.32"
+#define VERSION "10.1.32"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
